Auf dieser Seite

zabbix_sender

ZABBIX_SENDER(1)            Allgemeine Befehle            ZABBIX_SENDER(1)

NAME
       zabbix_sender - Zabbix-Sender-Dienstprogramm

SYNOPSIS
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

DESCRIPTION
       zabbix_sender ist ein Befehlszeilen-Dienstprogramm zum Senden von
       Überwachungsdaten an den Zabbix-Server oder Proxy. Auf dem Zabbix-Server
       sollte ein Datenpunkt vom Typ „Zabbix trapper“ mit dem entsprechenden
       Schlüssel erstellt werden. Beachten Sie, dass eingehende Werte nur von
       Hosts akzeptiert werden, die im Feld „Allowed hosts“ dieses Datenpunkts
       angegeben sind.

OPTIONS
       -c, --config config-file
              Verwendet  config-file.  Zabbix  sender liest die Serverdetails
              aus der Konfigurationsdatei von agentd. Standardmäßig liest
              Zabbix sender keine Konfigurationsdatei. Unterstützt werden nur
              die Parameter Hostname, ServerActive, SourceIP, TLSConnect,
              TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity
              und TLSPSKFile. Ein über den Parameter HostnameItem definierter
              Hostname wird nicht übernommen. In diesem Fall muss der Hostname
              über die Befehlszeile angegeben werden (siehe Option -s). Alle
              Adressen, die im Konfigurationsparameter ServerActive des Agent
              definiert sind, werden zum Senden von Daten verwendet. Wenn das
              Senden von Stapeldaten an eine Adresse fehlschlägt, werden die
              folgenden Stapel nicht an diese Adresse gesendet.

       -z, --zabbix-server server
              Hostname oder IP-Adresse des Zabbix-Servers. Wenn ein Host von
              einem Proxy überwacht wird, sollte stattdessen der Hostname oder
              die IP-Adresse des Proxy verwendet werden. Bei gemeinsamer
              Verwendung mit --config werden die Einträge des Parameters
              ServerActive in der agentd-Konfigurationsdatei überschrieben.

       -p, --port port
              Gibt die Portnummer an, unter der der Zabbix-Server-Trapper auf
              dem Server ausgeführt wird. Der Standardwert ist 10051. Bei
              gemeinsamer Verwendung mit --config werden die Porteinträge des
              Parameters ServerActive in der agentd-Konfigurationsdatei
              überschrieben.

       -I, --source-address IP-address
              Gibt die Quell-IP-Adresse an. Bei gemeinsamer Verwendung mit
              --config wird der Parameter SourceIP in der
              Konfigurationsdatei von agentd überschrieben.

       -t, --timeout seconds
              Gibt das Timeout an. Gültiger Bereich: 1-300 Sekunden
              (Standardwert: 60)

       -s, --host host
              Gibt den Hostnamen an, zu dem der Datenpunkt gehört (wie im
              Zabbix-Frontend registriert). Die IP-Adresse und der DNS-Name des
              Hosts funktionieren nicht. Bei gemeinsamer Verwendung mit
              --config wird der in der Konfigurationsdatei von agentd
              angegebene Parameter Hostname überschrieben.

       -k, --key key
              Gibt den Datenpunktschlüssel an, an den der Wert gesendet werden
              soll.

       -o, --value value
              Gibt den Datenpunktwert an.

       -i, --input-file input-file
              Lädt Werte aus der Eingabedatei. Geben Sie für <input-file> -
              an, um Werte aus der Standardeingabe zu lesen. Jede Zeile der
              Datei enthält durch Leerzeichen getrennte Werte:
              <hostname> <key> <value>. Jeder Wert muss in einer eigenen Zeile
              angegeben werden. Jede Zeile muss 3 durch Leerzeichen getrennte
              Einträge enthalten: <hostname> <key> <value>, wobei „hostname“
              der Name des überwachten Hosts ist, wie er im Zabbix-Frontend
              registriert ist, „key“ der Zieldatenpunktschlüssel und „value“
              der zu sendende Wert. Geben Sie für <hostname> - an, um den
              Hostnamen aus der Agent-Konfigurationsdatei oder aus dem
              Argument --host zu verwenden.

              Beispiel für eine Zeile einer Eingabedatei:

               "Linux DB3" db.connections 43

              Der Werttyp muss in der Datenpunktkonfiguration des
              Zabbix-Frontends korrekt festgelegt sein. Zabbix sender sendet
              bis zu 250 Werte über eine Verbindung. Der Inhalt der
              Eingabedatei muss UTF-8-codiert sein. Alle Werte aus der
              Eingabedatei werden in sequenzieller Reihenfolge von oben nach
              unten gesendet. Die Einträge müssen nach folgenden Regeln
              formatiert sein:

                     • In Anführungszeichen gesetzte und nicht in
                       Anführungszeichen gesetzte Einträge werden unterstützt.

                     • Das doppelte Anführungszeichen ist das
                       Anführungszeichen.

                     • Einträge mit Leerzeichen müssen in Anführungszeichen
                       gesetzt werden.

                     • Doppelte Anführungszeichen und umgekehrte
                       Schrägstriche innerhalb eines in Anführungszeichen
                       gesetzten Eintrags müssen mit einem umgekehrten
                       Schrägstrich maskiert werden.

                     • Maskierung wird in nicht in Anführungszeichen gesetzten
                       Einträgen nicht unterstützt.

                     • Escape-Sequenzen für Zeilenumbrüche (\n) werden in
                       Zeichenfolgen in Anführungszeichen unterstützt.

                     • Escape-Sequenzen für Zeilenumbrüche werden am Ende
                       eines Eintrags entfernt.

       -T, --with-timestamps
              Diese Option kann nur zusammen mit der Option --input-file
              verwendet werden.

              Jede Zeile der Eingabedatei muss 4 durch Leerzeichen getrennte
              Einträge enthalten: <hostname> <key> <timestamp> <value>. Der
              Zeitstempel muss im Unix-Zeitstempelformat angegeben werden.
              Wenn der Zieldatenpunkt Auslöser enthält, die auf ihn verweisen,
              müssen alle Zeitstempel in aufsteigender Reihenfolge angegeben
              werden, da die Ereignisberechnung andernfalls nicht korrekt ist.

              Beispiel für eine Zeile einer Eingabedatei:

               "Linux DB3" db.connections 1429533600 43

              Weitere Informationen finden Sie unter der Option --input-file.

              Wenn ein zeitgestempelter Wert für einen Host gesendet wird, der
              sich in einer Wartungsperiode vom Typ „no data“ befindet, wird
              dieser Wert verworfen. Es ist jedoch möglich, einen
              zeitgestempelten Wert für eine abgelaufene Wartungsperiode zu
              senden; dieser wird akzeptiert.

       -N, --with-ns
              Diese Option kann nur zusammen mit der Option --with-timestamps
              verwendet werden.

              Jede Zeile der Eingabedatei muss 5 durch Leerzeichen getrennte
              Einträge enthalten: <hostname> <key> <timestamp> <ns> <value>.

              Beispiel für eine Zeile einer Eingabedatei:

               "Linux DB3" db.connections 1429533600 7402561 43

              Weitere Informationen finden Sie unter der Option --input-file.

       -r, --real-time
              Sendet Werte einzeln, sobald sie empfangen werden. Dies kann
              beim Lesen aus der Standardeingabe verwendet werden.

       --tls-connect value
              Gibt an, wie eine Verbindung zum Server oder Proxy hergestellt
              wird. Werte:

                   unencrypted
                               Verbindung ohne Verschlüsselung
                               (Standardwert)

                   psk         Verbindung über TLS mit einem vorab
                               gemeinsam vereinbarten Schlüssel

                   cert        Verbindung über TLS mit einem Zertifikat

       --tls-ca-file CA-file
              Vollständiger Pfadname einer Datei, die die Zertifikate der
              übergeordneten Zertifizierungsstelle(n) zur Überprüfung des
              Peer-Zertifikats enthält.

       --tls-crl-file CRL-file
              Vollständiger Pfadname einer Datei, die widerrufene Zertifikate
              enthält.

       --tls-server-cert-issuer cert-issuer
              Zulässiger Aussteller des Serverzertifikats.

       --tls-server-cert-subject cert-subject
              Zulässiger Betreff des Serverzertifikats.

       --tls-cert-file cert-file
              Vollständiger Pfadname einer Datei, die das Zertifikat oder die
              Zertifikatskette enthält.

       --tls-key-file key-file
              Vollständiger Pfadname einer Datei, die den privaten Schlüssel
              enthält.

       --tls-psk-identity PSK-identity
              PSK-Identitätszeichenfolge.

       --tls-psk-file PSK-file
              Vollständiger Pfadname einer Datei, die den vorab gemeinsam
              vereinbarten Schlüssel enthält.

       --tls-cipher13 cipher-string
              Verschlüsselungszeichenfolge für OpenSSL 1.1.1 oder höher für
              TLS 1.3. Überschreibt die Kriterien für die standardmäßige
              Auswahl der Verschlüsselungssuite. Diese Option ist nicht
              verfügbar, wenn die OpenSSL-Version niedriger als 1.1.1 ist.

       --tls-cipher cipher-string
              GnuTLS-Prioritätszeichenfolge (für TLS 1.2 und höher) oder
              OpenSSL-Verschlüsselungszeichenfolge (nur für TLS 1.2).
              Überschreibt die Kriterien für die standardmäßige Auswahl der
              Verschlüsselungssuite.

       -v, --verbose
              Ausführlicher Modus; -vv liefert weitere Details.

       -h, --help
              Zeigt diese Hilfe an und beendet das Programm.

       -V, --version
              Gibt Versionsinformationen aus und beendet das Programm.

EXIT STATUS
       Der  Exit-Status ist 0, wenn die Werte gesendet und alle erfolgreich vom
       Server verarbeitet wurden. Wenn Daten gesendet wurden, die Verarbeitung
       mindestens eines Werts jedoch fehlgeschlagen ist, lautet der Exit-Status
       2. Wenn das Senden der Daten fehlgeschlagen ist, lautet der Exit-Status
       1.

EXAMPLES
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Sendet 342.45 als Wert für den Datenpunkt mysql.queries des
              überwachten Hosts. Verwendet den überwachten Host und den
              Zabbix-Server, die in der Agent-Konfigurationsdatei definiert
              sind.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Sendet 342.45 als Wert für den Datenpunkt mysql.queries des Hosts
              „Monitored Host“ und verwendet den in der
              Agent-Konfigurationsdatei definierten Zabbix-Server.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Sendet Werte aus der Datei data_values.txt an den Zabbix-Server
              mit der IP-Adresse 192.168.1.113. Hostnamen und Schlüssel sind in
              der Datei definiert.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Sendet einen zeitgestempelten Wert über die Befehlszeile an den
              in der Agent-Konfigurationsdatei angegebenen Zabbix-Server. Der
              Bindestrich in den Eingabedaten gibt an, dass der Hostname
              ebenfalls aus derselben Konfigurationsdatei verwendet werden
              soll.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Sendet einen leeren Wert eines Datenpunkts über die Befehlszeile
              an den Zabbix-Server mit der IP-Adresse 192.168.1.113 am Port
              10000. Leere Werte müssen durch leere doppelte Anführungszeichen
              angegeben werden.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Sendet 342.45 als Wert für den Datenpunkt mysql.queries des Hosts
              „Monitored Host“ an den Server mit der IP-Adresse 192.168.1.113
              und verwendet TLS mit einem Zertifikat.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Sendet 342.45 als Wert für den Datenpunkt mysql.queries des Hosts
              „Monitored Host“ an den Server mit der IP-Adresse 192.168.1.113
              und verwendet TLS mit einem vorab gemeinsam vereinbarten
              Schlüssel (PSK).

SEE ALSO
       Dokumentation

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)